/***********************************************************************/
/*                                                                     */
/*         USE THE GSS cycle 17 PUMF                                   */
/*         TO CALCULATE                                                */
/*         the number of people for which the highest level            */
/*         of education obtained is 'High school diploma' (EDU5 = 4)   */
/*         FOR THE AGE GROUPS 15-17, 18-24, 25-44, AND 45 AND OVER     */
/*         AND FOR MALES, FEMALES, AND BOTH,                           */
/*         BY PROVINCE                                                 */
/*                                                                     */
/***********************************************************************/

libname in1 'c:\data';

proc datasets kill;
run;

proc format;
  value fsex    1='males  '
                2='females';

  value fage    1='15-17'
                2='18-24'
                3='25-44'
                4='45+';

  value fedu    1='Yes'
                0='No ';
run;

data in1.ex1A;
%let datafid='c:\data\C17PUMFM.DAT';
%include 'c:\data\C17PUMFM_INPUT.sas';
keep regionc edu total agegr5 sex males females
     agegrp age1519 age2029 age3044 age45 magegrp fagegrp
     mage1519 mage2029 mage3044 mage45 fage1519 fage2029 fage3044 fage45
     medu fedu edu1519 edu2029 edu3044 edu45
     medu1519 medu2029 medu3044 medu45 fedu1519 fedu2029 fedu3044 fedu45
     wght_per total recid;

regionc=prv; 

if edu5=4 then edu=1;
else if edu5 in(1,2,3,5) then edu=0;
else edu=.;

if edu=. then delete;

/**********************************************/
/* define domains of interest with 0/1 values */
/**********************************************/

total=1;

 /* sex */

if sex=1 then males=1;
else males=0;

if sex=2 then females=1;
else females=0;


 /* age group */

if agegr5 < 3 then agegrp=1;
else if agegr5 < 5 then agegrp=2;
else if agegr5 < 8 then agegrp=3;
else agegrp=4;

if agegrp=1 then age1519=1; else age1519=0;
if agegrp=2 then age2029=1; else age2029=0;
if agegrp=3 then age3044=1; else age3044=0;
if agegrp=4 then age45=1; else age45=0;


 /* age group and sex */

if agegrp=1 then do;
  if sex=1 then magegrp=1;
  else if sex=2 then fagegrp=1;
end;
else if agegrp=2 then do;
  if sex=1 then magegrp=2;
  else if sex=2 then fagegrp=2;
end;
else if agegrp=3 then do;
  if sex=1 then magegrp=3;
  else if sex=2 then fagegrp=3;
end;
else if agegrp=4 then do;
  if sex=1 then magegrp=4;
  else if sex=2 then fagegrp=4;
end;

if magegrp=1 then mage1519=1; else mage1519=0;
if magegrp=2 then mage2029=1; else mage2029=0;
if magegrp=3 then mage3044=1; else mage3044=0;
if magegrp=4 then mage45=1; else mage45=0;

if fagegrp=1 then fage1519=1; else fage1519=0;
if fagegrp=2 then fage2029=1; else fage2029=0;
if fagegrp=3 then fage3044=1; else fage3044=0;
if fagegrp=4 then fage45=1; else fage45=0;


 /* edu5*sex */

if edu=1 then do;
  if sex=1 then medu=1; else medu=0;   /* edu5=4 males   */
  if sex=2 then fedu=1; else fedu=0;   /* edu5=4 females */
end;
else do;
  medu=0;
  fedu=0;
end;


 /* edu5*age group */

if edu=1 then do;
  if age1519=1 then edu1519=1; else edu1519=0;
  if age2029=1 then edu2029=1; else edu2029=0;
  if age3044=1 then edu3044=1; else edu3044=0;
  if age45=1   then edu45=1; else edu45=0;
end;
else do;
  edu1519=0;
  edu2029=0;
  edu3044=0;
  edu45=0;
end;


 /* edu5*sex*age group */

if medu=1 then do;
  if age1519=1 then medu1519=1; else medu1519=0;
  if age2029=1 then medu2029=1; else medu2029=0;
  if age3044=1 then medu3044=1; else medu3044=0;
  if age45=1   then medu45=1; else medu45=0;
end;
else do;
  medu1519=0;
  medu2029=0;
  medu3044=0;
  medu45=0;
end;

if fedu=1 then do;
  if age1519=1 then fedu1519=1; else fedu1519=0;
  if age2029=1 then fedu2029=1; else fedu2029=0;
  if age3044=1 then fedu3044=1; else fedu3044=0;
  if age45=1   then fedu45=1; else fedu45=0;
end;
else do;
  fedu1519=0;
  fedu2029=0;
  fedu3044=0;
  fedu45=0;
end;

proc freq data=in1.ex1A;
format agegrp fage. magegrp fage. fagegrp fage. edu fedu.;
table regionc*(edu edu3044 medu3044 fedu3044)
regionc*edu*total regionc*medu3044*mage3044 regionc*edu3044*age3044 ;
weight wght_per;
label regionc='province';
title1 'Number of people for which the highest level';  
title2 'of education obtained is High school diploma (EDU5 = 4)'; 
title3 'by age group and regionc (province)';
run;
